@@ -602,7 +602,7 @@ class GTE(Binary):
     pass
 
 
-class Is(Binary):
+class ILike(Binary):
     pass
 
 
@@ -610,6 +610,10 @@ class IntDiv(Binary):
     pass
 
 
+class Is(Binary):
+    pass
+
+
 class Like(Binary):
     pass
 
@@ -713,6 +717,10 @@ class Interval(Expression):
     arg_types = {"this": True, "unit": True}
 
 
+class TryCast(Cast):
+    pass
+
+
 # Functions
 class Func(Expression):
     """
@@ -901,6 +909,10 @@ class Log10(Func):
     pass
 
 
+class Lower(Func):
+    pass
+
+
 class Map(Func):
     arg_types = {"keys": True, "values": True}
     is_var_len_args = True
@@ -1031,6 +1043,10 @@ class UnixToTimeStr(Func):
     pass
 
 
+class Upper(Func):
+    pass
+
+
 class Variance(AggFunc):
     pass
 
